package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppTourist;

/**
 * 游客Service接口
 * 
 * @author ruoyi
 * @date 2025-03-06
 */
public interface IAppTouristService 
{
    /**
     * 查询游客
     * 
     * @param id 游客主键
     * @return 游客
     */
    public AppTourist selectAppTouristById(Long id);

    /**
     * 查询游客列表
     * 
     * @param appTourist 游客
     * @return 游客集合
     */
    public List<AppTourist> selectAppTouristList(AppTourist appTourist);

    /**
     * 新增游客
     * 
     * @param appTourist 游客
     * @return 结果
     */
    public int insertAppTourist(AppTourist appTourist);

    /**
     * 修改游客
     * 
     * @param appTourist 游客
     * @return 结果
     */
    public int updateAppTourist(AppTourist appTourist);

    /**
     * 批量删除游客
     * 
     * @param ids 需要删除的游客主键集合
     * @return 结果
     */
    public int deleteAppTouristByIds(Long[] ids);

    /**
     * 删除游客信息
     * 
     * @param id 游客主键
     * @return 结果
     */
    public int deleteAppTouristById(Long id);

    /**
     * 查询单个游客
     *
     * @return 游客
     */
    public AppTourist getAppTouristLimitOne();
}
