package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppTourist;
import com.ruoyi.model.service.IAppTouristService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 游客Controller
 * 
 * @author ruoyi
 * @date 2025-03-06
 */
@RestController
@RequestMapping("/model/AppTourist")
public class AppTouristController extends BaseController
{
    @Autowired
    private IAppTouristService appTouristService;

    /**
     * 查询游客列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppTourist:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppTourist appTourist)
    {
        startPage();
        List<AppTourist> list = appTouristService.selectAppTouristList(appTourist);
        return getDataTable(list);
    }

    /**
     * 导出游客列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppTourist:export')")
    @Log(title = "游客", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppTourist appTourist) throws IOException {
        List<AppTourist> list = appTouristService.selectAppTouristList(appTourist);
        ExcelUtil<AppTourist> util = new ExcelUtil<AppTourist>(AppTourist.class);
        util.exportExcel(response, list, "游客数据");
    }

    /**
     * 获取游客详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppTourist:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appTouristService.selectAppTouristById(id));
    }

    /**
     * 新增游客
     */
    @PreAuthorize("@ss.hasPermi('model:AppTourist:add')")
    @Log(title = "游客", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppTourist appTourist)
    {
        return toAjax(appTouristService.insertAppTourist(appTourist));
    }

    /**
     * 修改游客
     */
    @PreAuthorize("@ss.hasPermi('model:AppTourist:edit')")
    @Log(title = "游客", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppTourist appTourist)
    {
        return toAjax(appTouristService.updateAppTourist(appTourist));
    }

    /**
     * 删除游客
     */
    @PreAuthorize("@ss.hasPermi('model:AppTourist:remove')")
    @Log(title = "游客", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appTouristService.deleteAppTouristByIds(ids));
    }
}
